@@ -1,26 +1,31 @@
 /*
- * $Id$
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.config.spring;
 
+import org.mule.DefaultMuleContext;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleRuntimeException;
 import org.mule.api.config.ConfigurationException;
 import org.mule.api.config.MuleConfiguration;
+import org.mule.api.config.MuleProperties;
 import org.mule.api.context.MuleContextAware;
 import org.mule.api.exception.MessagingExceptionHandler;
 import org.mule.api.exception.MessagingExceptionHandlerAcceptor;
+import org.mule.api.processor.ProcessingStrategy;
+import org.mule.api.serialization.ObjectSerializer;
 import org.mule.config.DefaultMuleConfiguration;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.MessageFactory;
+import org.mule.config.spring.util.ProcessingStrategyUtils;
+import org.mule.serialization.internal.JavaObjectSerializer;
 
+import java.util.List;
+
+import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.springframework.beans.factory.SmartFactoryBean;
@@ -70,7 +75,12 @@ public class MuleConfigurationConfigurator implements MuleContextAware, SmartFac
             defaultConfig.setFlowEndingWithOneWayEndpointReturnsNull(config.isFlowEndingWithOneWayEndpointReturnsNull());
             defaultConfig.setDefaultExceptionStrategyName(config.getDefaultExceptionStrategyName());
             defaultConfig.setEnricherPropagatesSessionVariableChanges(config.isEnricherPropagatesSessionVariableChanges());
+            defaultConfig.setExtensions(config.getExtensions());
+            defaultConfig.setMaxQueueTransactionFilesSize(config.getMaxQueueTransactionFilesSizeInMegabytes());
+            determineDefaultProcessingStrategy(defaultConfig);
             validateDefaultExceptionStrategy();
+            applyDefaultIfNoObjectSerializerSet(defaultConfig);
+
             return configuration;
         }
         else
@@ -79,6 +89,22 @@ public class MuleConfigurationConfigurator implements MuleContextAware, SmartFac
         }
     }
 
+    private void determineDefaultProcessingStrategy(DefaultMuleConfiguration defaultConfig)
+    {
+        if (config.getDefaultProcessingStrategy() != null)
+        {
+            defaultConfig.setDefaultProcessingStrategy(config.getDefaultProcessingStrategy());
+        }
+        else
+        {
+            String processingStrategyFromSystemProperty = System.getProperty(MuleProperties.MULE_DEFAULT_PROCESSING_STRATEGY);
+            if (!StringUtils.isBlank(processingStrategyFromSystemProperty))
+            {
+                defaultConfig.setDefaultProcessingStrategy(ProcessingStrategyUtils.parseProcessingStrategy(processingStrategyFromSystemProperty));
+            }
+        }
+    }
+
     private void validateDefaultExceptionStrategy()
     {
         String defaultExceptionStrategyName = config.getDefaultExceptionStrategyName();
@@ -103,6 +129,23 @@ public class MuleConfigurationConfigurator implements MuleContextAware, SmartFac
         }
     }
 
+    private void applyDefaultIfNoObjectSerializerSet(DefaultMuleConfiguration configuration)
+    {
+        ObjectSerializer configuredSerializer = config.getDefaultObjectSerializer();
+        if (configuredSerializer == null)
+        {
+            configuredSerializer = new JavaObjectSerializer();
+            ((MuleContextAware) configuredSerializer).setMuleContext(muleContext);
+            config.setDefaultObjectSerializer(configuredSerializer);
+        }
+
+        configuration.setDefaultObjectSerializer(configuredSerializer);
+        if (muleContext instanceof DefaultMuleContext)
+        {
+            ((DefaultMuleContext) muleContext).setObjectSerializer(configuredSerializer);
+        }
+    }
+
     public Class<?> getObjectType()
     {
         return MuleConfiguration.class;
@@ -153,4 +196,24 @@ public class MuleConfigurationConfigurator implements MuleContextAware, SmartFac
         config.setEnricherPropagatesSessionVariableChanges(enricherPropagatesSessionVariableChanges);
     }
 
+    public void setDefaultObjectSerializer(ObjectSerializer objectSerializer)
+    {
+        config.setDefaultObjectSerializer(objectSerializer);
+    }
+
+    public void setDefaultProcessingStrategy(ProcessingStrategy processingStrategy)
+    {
+        config.setDefaultProcessingStrategy(processingStrategy);
+    }
+
+    public void setMaxQueueTransactionFilesSize(int queueTransactionFilesSizeInMegabytes)
+    {
+        config.setMaxQueueTransactionFilesSize(queueTransactionFilesSizeInMegabytes);
+    }
+
+    public void setExtensions(List<Object> extensions)
+    {
+        config.setExtensions(extensions);
+    }
+
 }
