@@ -1,13 +1,9 @@
 /*
- * $Id: RoutingNotification.java 19191 2010-08-25 21:05:23Z tcarlson $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.context.notification;
 
 import org.mule.api.MuleMessage;
@@ -38,7 +34,7 @@ public class RoutingNotification extends ServerNotification
 
     public RoutingNotification(MuleMessage resource, String identifier, int action)
     {
-        super(cloneMessage(resource), action);
+        super(resource, action);
         resourceIdentifier = identifier;
     }
 
