@@ -1,13 +1,9 @@
 /*
- * $Id:AbstractExternalTransactionTestCase.java 8215 2007-09-05 16:56:51Z aperepel $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.execution;
 
 import org.mule.api.execution.ExecutionCallback;
@@ -15,7 +11,7 @@ import org.mule.api.execution.ExecutionCallback;
 class ExecuteCallbackInterceptor<T> implements ExecutionInterceptor<T>
 {
     @Override
-    public T execute(ExecutionCallback<T> callback) throws Exception
+    public T execute(ExecutionCallback<T> callback, ExecutionContext executionContext) throws Exception
     {
         return callback.process();
     }
