@@ -1,18 +1,13 @@
 /*
- * $Id: PollingReceiverWorker.java 22396 2011-07-12 21:26:04Z mike.schilling $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.transport;
 
 import org.mule.RequestContext;
 import org.mule.api.MessagingException;
-import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 
 import javax.resource.spi.work.Work;
@@ -32,7 +27,7 @@ public class PollingReceiverWorker implements Work
     {
         return receiver;
     }
-    
+
     public boolean isRunning()
     {
         return running;
@@ -61,17 +56,16 @@ public class PollingReceiverWorker implements Work
                 }
                 catch (MuleException e1)
                 {
-                    receiver.getConnector().getMuleContext().getExceptionListener().handleException(e1);
+                    receiver.getEndpoint().getMuleContext().getExceptionListener().handleException(e1);
                 }
             }
             catch (MessagingException e)
             {
-                MuleEvent event = (e).getEvent();
-                event.getFlowConstruct().getExceptionListener().handleException(e, event);
+                //Already handled by TransactionTemplate
             }
             catch (Exception e)
             {
-                receiver.getConnector().getMuleContext().getExceptionListener().handleException(e);
+                receiver.getEndpoint().getMuleContext().getExceptionListener().handleException(e);
             }
             finally
             {
@@ -82,6 +76,11 @@ public class PollingReceiverWorker implements Work
 
     protected void poll() throws Exception
     {
+        if (this.receiver.getFlowConstruct().getMuleContext().isStopping())
+        {
+            return;
+        }
+
         receiver.performPoll();
     }
 
