@@ -1,8 +1,5 @@
 /*
- * $Id: JmsEndpointURIBuilder.java 20321 2010-11-24 15:21:24Z dfeist $
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
@@ -26,6 +23,8 @@ public class JmsEndpointURIBuilder extends ResourceNameEndpointURIBuilder
     {
         super.setEndpoint(uri, props);
 
+		String oldUri = uri.toString();
+
         String newUri = null;
         if (uri.getScheme().equals("topic"))
         {
@@ -35,7 +34,20 @@ public class JmsEndpointURIBuilder extends ResourceNameEndpointURIBuilder
         else if (uri.getScheme().equals("queue"))
         {
             newUri = uri.toString().replace("queue://", "jms://");
-        }
+        }//Added by Eugene - dynamic endpoints were resolved to jms://queue:// etc
+		else if (oldUri.startsWith("jms://queue://"))
+		{
+			newUri = uri.toString().replace("jms://queue://", "jms://queue:");
+		}
+		else if (oldUri.startsWith("jms://temp-queue://"))
+		{
+			newUri = uri.toString().replace("jms://temp-queue://", "jms://temp-queue:");
+		}
+		else if (oldUri.startsWith("jms://topic://"))
+		{
+			props.setProperty(RESOURCE_INFO_PROPERTY, "topic");
+			newUri = uri.toString().replace("jms://topic://", "jms://topic:");
+		}
 
         try
         {
@@ -48,6 +60,5 @@ public class JmsEndpointURIBuilder extends ResourceNameEndpointURIBuilder
         {
             throw new MalformedEndpointException(e);
         }
-
     }
 }
