@@ -83,6 +83,12 @@ public class QuartzMessageReceiver extends AbstractMessageReceiver
     {
         try
         {
+
+            if (connector.getQuartzScheduler().isInStandbyMode())
+            {
+                connector.getQuartzScheduler().start();
+            }
+
             Scheduler scheduler = connector.getQuartzScheduler();
 
             JobConfig jobConfig = (JobConfig) endpoint.getProperty(QuartzConnector.PROPERTY_JOB_CONFIG);
@@ -196,5 +202,12 @@ public class QuartzMessageReceiver extends AbstractMessageReceiver
     {
         // nothing to do
     }
+    
+    @Override
+    protected void doStop() throws MuleException
+    {
+        super.doStop();
+        connector.doStop();
+    }
 
 }
