@@ -1,8 +1,5 @@
 /*
- * $Id$
- * -------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
@@ -14,7 +11,7 @@ import org.mule.api.transport.MessageReceiver;
 
 import javax.servlet.Servlet;
 
-import org.mortbay.jetty.Connector;
+import org.eclipse.jetty.server.Connector;
 
 /**
  * TODO
