@@ -1,13 +1,9 @@
 /*
- * $Id$
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
-
 package org.mule.transport.ssl;
 
 import org.mule.api.MuleContext;
@@ -16,8 +12,6 @@ import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.security.TlsDirectKeyStore;
 import org.mule.api.security.TlsDirectTrustStore;
 import org.mule.api.security.TlsIndirectKeyStore;
-import org.mule.api.security.TlsProtocolHandler;
-import org.mule.api.security.provider.SecurityProviderFactory;
 import org.mule.api.security.tls.TlsConfiguration;
 import org.mule.transport.tcp.TcpConnector;
 import org.mule.transport.tcp.protocols.DirectProtocol;
@@ -25,7 +19,6 @@ import org.mule.transport.tcp.protocols.DirectProtocol;
 import java.io.IOException;
 import java.net.ServerSocket;
 import java.net.URI;
-import java.security.Provider;
 
 import javax.net.ssl.KeyManagerFactory;
 import javax.net.ssl.SSLServerSocket;
@@ -37,7 +30,7 @@ import javax.net.ssl.TrustManagerFactory;
  * provide SSL enabled sockets.  All other logic is identical to TCP.
  */
 public class SslConnector extends TcpConnector
-        implements TlsDirectKeyStore, TlsIndirectKeyStore, TlsDirectTrustStore, TlsProtocolHandler
+        implements TlsDirectKeyStore, TlsIndirectKeyStore, TlsDirectTrustStore
 {
 
     public static final String SSL = "ssl";
@@ -138,21 +131,6 @@ public class SslConnector extends TcpConnector
         return tls.getKeyStoreType();
     }
 
-    public String getProtocolHandler()
-    {
-        return tls.getProtocolHandler();
-    }
-
-    public Provider getProvider()
-    {
-        return tls.getProvider();
-    }
-
-    public SecurityProviderFactory getSecurityProviderFactory()
-    {
-        return tls.getSecurityProviderFactory();
-    }
-
     public String getSslType()
     {
         return tls.getSslType();
@@ -243,26 +221,11 @@ public class SslConnector extends TcpConnector
         tls.setKeyStoreType(keystoreType);
     }
 
-    public void setProtocolHandler(String protocolHandler)
-    {
-        tls.setProtocolHandler(protocolHandler);
-    }
-
-    public void setProvider(Provider provider)
-    {
-        tls.setProvider(provider);
-    }
-
     public void setRequireClientAuthentication(boolean requireClientAuthentication)
     {
         tls.setRequireClientAuthentication(requireClientAuthentication);
     }
 
-    public void setSecurityProviderFactory(SecurityProviderFactory spFactory)
-    {
-        tls.setSecurityProviderFactory(spFactory);
-    }
-
     public void setSslType(String sslType)
     {
         tls.setSslType(sslType);
