@@ -68,15 +68,15 @@ public class TransactionJournal<T, K extends JournalEntry<T>>
         File logFileDirectory = new File(logFilesDirectory);
         if (!logFileDirectory.exists())
         {
-            Preconditions.checkState(logFileDirectory.mkdirs(), "Could not created directory for queue transaction logger " + logFileDirectory);
+            Preconditions.checkState(logFileDirectory.mkdirs(), "Could not create directory for queue transaction logger " + logFileDirectory);
         }
         calculateJournalFileSize(maximumFileSizeInMegabytes);
         File logFile1 = new File(logFileDirectory, TX1_LOG_FILE_NAME);
         File logFile2 = new File(logFileDirectory, TX2_LOG_FILE_NAME);
         logger.info(String.format("Using files for tx logs %s and %s", logFile1.getAbsolutePath(), logFile2.getAbsolutePath()));
 
-        this.currentLogFile = new TransactionJournalFile(logFile1, journalEntrySerializer, clearFileMinimumSizeInBytes);
-        this.notCurrentLogFile = new TransactionJournalFile(logFile2, journalEntrySerializer, clearFileMinimumSizeInBytes);
+        this.currentLogFile = new TransactionJournalFile(logFile1, journalEntrySerializer, transactionCompletePredicate, clearFileMinimumSizeInBytes);
+        this.notCurrentLogFile = new TransactionJournalFile(logFile2, journalEntrySerializer, transactionCompletePredicate, clearFileMinimumSizeInBytes);
         this.transactionCompletePredicate = transactionCompletePredicate;
 
     }
