@@ -1,18 +1,16 @@
 /*
- * $Id$
- * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
- *
  * The software in this package is published under the terms of the CPAL v1.0
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
 package org.mule.util.store;
 
+import static org.mule.util.IOUtils.closeQuietly;
+
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.store.ObjectStoreException;
 import org.mule.util.FileUtils;
-import org.mule.util.IOUtils;
 import org.mule.util.StringUtils;
 
 import java.io.File;
@@ -99,9 +97,7 @@ public class TextFileObjectStore extends InMemoryObjectStore<String>
                 output = new FileOutputStream(fileStore, true);
             }
 
-            StringBuffer buf = new StringBuffer();
-            buf.append(id).append("=").append(item).append(IOUtils.LINE_SEPARATOR);
-            output.write(buf.toString().getBytes());
+            updateTextFile();
         }
         catch (IOException iox)
         {
@@ -109,6 +105,47 @@ public class TextFileObjectStore extends InMemoryObjectStore<String>
         }
     }
 
+    @Override
+    public void expire()
+    {
+        int expiredEntries = doTrimAndExpire();
+
+        if (expiredEntries > 0)
+        {
+            updateTextFile();
+        }
+
+        if (logger.isDebugEnabled() && expiredEntries != 0)
+        {
+            logger.debug("Expired " + expiredEntries + " old entries");
+        }
+    }
+
+    private void updateTextFile()
+    {
+        Properties props = getStoreAsProperties();
+
+        try
+        {
+            if (output != null)
+            {
+                closeQuietly(output);
+            }
+            output = new FileOutputStream(fileStore, false);
+            props.store(output, StringUtils.EMPTY);
+        }
+        catch (IOException e)
+        {
+            logger.error(e.getMessage(), e);
+        }
+    }
+
+    @Override
+    public void clear()
+    {
+        throw new UnsupportedOperationException();
+    }
+
     public String getDirectory()
     {
         return directory;
@@ -132,13 +169,7 @@ public class TextFileObjectStore extends InMemoryObjectStore<String>
     @Override
     public synchronized void dispose()
     {
-        Properties props = new Properties();
-
-        for (Iterator<?> iterator = super.store.values().iterator(); iterator.hasNext();)
-        {
-            StoredObject<?> storedObject = (StoredObject<?>) iterator.next();
-            props.put(storedObject.getId(), storedObject.getItem());
-        }
+        Properties props = getStoreAsProperties();
 
         if (output == null)
         {
@@ -146,7 +177,7 @@ public class TextFileObjectStore extends InMemoryObjectStore<String>
             {
                 output = new FileOutputStream(fileStore, false);
                 props.store(output, StringUtils.EMPTY);
-                IOUtils.closeQuietly(output);
+                closeQuietly(output);
             }
             catch (IOException e)
             {
@@ -155,9 +186,21 @@ public class TextFileObjectStore extends InMemoryObjectStore<String>
         }
         else
         {
-            IOUtils.closeQuietly(output);
+            closeQuietly(output);
         }
 
         super.dispose();
     }
+
+    private Properties getStoreAsProperties()
+    {
+        Properties props = new Properties();
+
+        for (Iterator<?> iterator = super.store.values().iterator(); iterator.hasNext(); )
+        {
+            StoredObject<?> storedObject = (StoredObject<?>) iterator.next();
+            props.put(storedObject.getId(), storedObject.getItem());
+        }
+        return props;
+    }
 }
