@@ -8,6 +8,7 @@ package org.mule.work;
 
 import org.mule.DefaultMuleEvent;
 import org.mule.OptimizedRequestContext;
+import org.mule.RequestContext;
 import org.mule.api.MuleEvent;
 
 import javax.resource.spi.work.Work;
@@ -29,18 +30,37 @@ public abstract class AbstractMuleEventWork implements Work
     {
         // Event must be copied here rather than once work is executed, so main flow can't mutate the message
         // before work execution
-        this.event = DefaultMuleEvent.copy(event);
+        this(event, true);
     }
 
+    /**
+     * Constructor allowing event copying to be disabled.  This is used when a copy has already been made previously
+     * e.g.  if the event is queued before being processed asynchronously like with {@link org.mule.processor
+     * .SedaStageInterceptingMessageProcessor}
+     */
+    public AbstractMuleEventWork(MuleEvent event, boolean copyEvent)
+    {
+        this.event = copyEvent ? DefaultMuleEvent.copy(event) : event;
+    }
+
+    @Override
     public final void run()
     {
-        // Set event in RequestContext now we are in new thread (fresh copy already made in constructor)
-        OptimizedRequestContext.unsafeSetEvent(event);
-        doRun();
+        try
+        {
+            // Set event in RequestContext now we are in new thread (fresh copy already made in constructor)
+            OptimizedRequestContext.unsafeSetEvent(event);
+            doRun();
+        }
+        finally
+        {
+            RequestContext.clear();
+        }
     }
 
     protected abstract void doRun();
 
+    @Override
     public void release()
     {
         // no-op
